package com.tencent.mlvb.thirdbeauty;

import static com.tencent.live2.V2TXLiveDef.V2TXLiveBufferType.V2TXLiveBufferTypeTexture;
import static com.tencent.live2.V2TXLiveDef.V2TXLivePixelFormat.V2TXLivePixelFormatTexture2D;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.Nullable;

import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.live2.V2TXLiveDef;
import com.tencent.live2.V2TXLivePusher;
import com.tencent.live2.V2TXLivePusherObserver;
import com.tencent.live2.impl.V2TXLivePusherImpl;
import com.tencent.mlvb.common.MLVBBaseActivity;
import com.tencent.mlvb.debug.AddressUtils;
import com.tencent.rtmp.ui.TXCloudVideoView;
import com.tencent.xmagic.XMagicImpl;
import com.tencent.xmagic.XmagicLoadAssetsView;
import com.tencent.xmagic.module.XmagicResParser;
import com.tencent.xmagic.panel.XmagicPanelDataManager;
import com.tencent.xmagic.telicense.TELicenseCheck;

import java.util.Random;

/**
 * TRTC 第三方美颜页面
 * <p>
 * 首先需要调用 {@link V2TXLivePusher#enableCustomVideoProcess(boolean, V2TXLiveDef.V2TXLivePixelFormat, V2TXLiveDef.V2TXLiveBufferType)}  }开启自定义视频处理，才会收到这个回调通知。
 * - 首先在推流之前调用{@link V2TXLivePusher#enableCustomVideoProcess(boolean, V2TXLiveDef.V2TXLivePixelFormat, V2TXLiveDef.V2TXLiveBufferType)},设置开启自定义渲染
 * - 然后掉用{@link V2TXLivePusher#setObserver(V2TXLivePusherObserver)} 监听SDK的视频数据
 * - 当收到数据时，在{@link V2TXLivePusherObserver#onProcessVideoFrame(V2TXLiveDef.V2TXLiveVideoFrame, V2TXLiveDef.V2TXLiveVideoFrame)}中适应第三方的美颜组件去处理。
 * <p>
 * 本Demo集成的是腾讯Xmagic美颜功能
 */
public class ThirdBeautyActivity extends MLVBBaseActivity implements View.OnClickListener {
    private static final String TAG = "ThirdBeautyActivity";

    private TXCloudVideoView mPushRenderView;
    private V2TXLivePusher mLivePusher;
    private EditText mEditStreamId;
    private Button mButtonPush;
    private TextView mTextTitle;
    private XMagicImpl mXMagic;
    private RelativeLayout mBeautyPanelView;
    private boolean isGLContextCreated = true;
    private boolean isPushing = false;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.thirdbeauty_activity_third_beauty);
        if (checkPermission()) {
            initView();
            auth();
        }
    }

    /**
     *
     */
    private void auth() {
        XMagicImpl.checkAuth((errorCode, msg) -> {
            if (errorCode == TELicenseCheck.ERROR_OK) {
                showLoadResourceView();
            } else {
                TXCLog.e(TAG, "鉴权失败，请检查鉴权url和key" + errorCode + " " + msg);
            }
        });
    }

    /**
     * 初始化美颜SDK
     */
    private void initXMagic() {
        if (mXMagic == null) {
            mXMagic = new XMagicImpl(this, mBeautyPanelView);
        } else {
            mXMagic.onResume();
        }
    }


    @Override
    protected void onPermissionGranted() {
        initView();
        auth();
    }

    private void showLoadResourceView() {
        if (XmagicLoadAssetsView.isCopyedRes) {
            XmagicResParser.parseRes(getApplicationContext());
            initXMagic();
        } else {
            XmagicLoadAssetsView loadAssetsView = new XmagicLoadAssetsView(this);
            loadAssetsView.setOnAssetsLoadFinishListener(() -> {
                XmagicResParser.parseRes(getApplicationContext());
                initXMagic();
            });
        }
    }

    private void initView() {
        mPushRenderView = findViewById(R.id.pusher_tx_cloud_view);
        mButtonPush = findViewById(R.id.btn_push);
        mEditStreamId = findViewById(R.id.et_stream_id);
        mTextTitle = findViewById(R.id.tv_title);
        mBeautyPanelView = findViewById(R.id.livepusher_bp_beauty_pannel);
        mEditStreamId.setText(generateStreamId());
        findViewById(R.id.iv_back).setOnClickListener(this);
        mButtonPush.setOnClickListener(this);
        if (!TextUtils.isEmpty(mEditStreamId.getText().toString())) {
            mTextTitle.setText(mEditStreamId.getText().toString());
        }
    }

    private void startPush() {
        String streamId = mEditStreamId.getText().toString();
        if (TextUtils.isEmpty(streamId)) {
            Toast.makeText(ThirdBeautyActivity.this, getString(R.string.thirdbeauty_please_input_streamd), Toast.LENGTH_SHORT).show();
            return;
        }
        mTextTitle.setText(streamId);
        String userId = String.valueOf(new Random().nextInt(10000));
        String pushUrl = AddressUtils.generatePushUrl(streamId, userId, 0);
        mLivePusher = new V2TXLivePusherImpl(this, V2TXLiveDef.V2TXLiveMode.TXLiveMode_RTC);

        mLivePusher.enableCustomVideoProcess(true, V2TXLivePixelFormatTexture2D, V2TXLiveBufferTypeTexture);
        mLivePusher.setObserver(new V2TXLivePusherObserver() {
            @Override
            public void onGLContextCreated() {
                Log.d("sunny------", "1");
                //2. GLContext 创建
                if (isGLContextCreated) {
                    isGLContextCreated = false;
                } else {
                    runOnUiThread(() -> initXMagic());
                }
            }

            @Override
            public int onProcessVideoFrame(V2TXLiveDef.V2TXLiveVideoFrame srcFrame, V2TXLiveDef.V2TXLiveVideoFrame dstFrame) {
                if (mXMagic != null) {
                    dstFrame.texture.textureId = mXMagic.process(srcFrame.texture.textureId, srcFrame.width, srcFrame.height);
                }
                return srcFrame.texture.textureId;
            }

            @Override
            public void onGLContextDestroyed() {
                Log.d("sunny------", "3");
                if (mXMagic != null) {
                    mXMagic.onDestroy();
                }
            }
        });
        mLivePusher.setRenderView(mPushRenderView);
        mLivePusher.startCamera(true);
        int ret = mLivePusher.startPush(pushUrl);
        Log.i(TAG, "startPush return: " + ret);
        mLivePusher.startMicrophone();
        mButtonPush.setText(R.string.thirdbeauty_stop_push);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mLivePusher != null) {
            mLivePusher.stopCamera();
            mLivePusher.stopMicrophone();
            if (mLivePusher.isPushing() == 1) {
                mLivePusher.stopPush();
            }
            mLivePusher = null;
            XmagicPanelDataManager.getInstance().clearData();
        }
    }

    @Override
    public void onBackPressed() {
        finish();
    }

    @Override
    public void onClick(View view) {
        int id = view.getId();
        if (id == R.id.btn_push) {
            push();
        } else if (id == R.id.iv_back) {
            finish();
        }
    }


    private void push() {
        if (mLivePusher != null) {
            Log.d("sunny------", "mLivePusher.isPushing()=" + mLivePusher.isPushing());
        }
        if (isPushing) {
            isPushing = false;
            stopPush();
        } else {
            isPushing = true;
            startPush();
        }
    }

    private void stopPush() {
        if (mLivePusher != null) {
            mLivePusher.stopCamera();
            mLivePusher.stopMicrophone();
            if (mLivePusher.isPushing() == 1) {
                mLivePusher.stopPush();
            }
            mLivePusher = null;
        }
        mButtonPush.setText(R.string.thirdbeauty_start_push);
    }


    @Override
    protected void onResume() {
        super.onResume();
        if(mXMagic!=null){
            mXMagic.onResume();
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        if (mXMagic != null) {
            mXMagic.onPause();
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (mXMagic != null) {
            mXMagic.onActivityResult(requestCode, resultCode, data);
        }
    }
}
